==> limigrations-1.1.0.tar.gz: limigrations-1.1.0/setup.py <==
# -*- coding: utf-8 -*-
"""The setup for limigrations package.

See:
https://github.com/dragosthealex/limigrations
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()
    long_description = long_description.replace("\r", "")

setup(
    name='limigrations',
    version='1.1.0',
    description='Lightweight migrations system for python / sqlite3',
    long_description=long_description,

    # The project's main homepage.
    url='https://github.com/dragosthealex/limigrations',

    # Author details
    author='Alex Radu',
    author_email='alex.radu.1000@gmail.com',

    # Choose your license
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # Development status
        'Development Status :: 5 - Production/Stable',

        # Audience and topics
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'Topic :: Database',
        'Topic :: Software Development :: Version Control',
        'Topic :: Utilities',

        # License
        'License :: OSI Approved :: MIT License',

        # Language
        'Natural Language :: English',

        # Python support
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],

    # What does your project relate to?
    keywords='migrations sqlite3 database development verson-control',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),

    # Alternatively, if you want to distribute just a my_module.py, uncomment
    # this:
    #   py_modules=["my_module"],

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=[],

    # List additional groups of dependencies here (e.g. development
    # dependencies). You can install these using the following syntax,
    # for example:
    # $ pip install -e .[dev,test]
    extras_require={
    },

    # If there are data files included in your packages that need to be
    # installed, specify them here.  If using Python 2.6 or less, then these
    # have to be included in MANIFEST.in as well.
    package_data={
    },

    # Although 'package_data' is the preferred approach, in some case you may
    # need to place data files outside of your packages. See:
    # http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files # noqa
    # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
    data_files=[],

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    entry_points={
        'console_scripts': [
            'limigrations=limigrations:main',
        ],
    },
)

==> limigrations-1.1.1.tar.gz: limigrations-1.1.1/setup.py <==
# -*- coding: utf-8 -*-
"""The setup for limigrations package.

See:
https://github.com/dragosthealex/limigrations
"""

# Always prefer setuptools over distutils
from setuptools import setup, find_packages
# To use a consistent encoding
from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()
    long_description = long_description.replace("\r", "")

setup(
    name='limigrations',
    version='1.1.1',
    description='Lightweight migrations system for python / sqlite3',
    long_description=long_description,

    # The project's main homepage.
    url='https://github.com/dragosthealex/limigrations',

    # Author details
    author='Alex Radu',
    author_email='alex.radu.1000@gmail.com',

    # Choose your license
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # Development status
        'Development Status :: 5 - Production/Stable',

        # Audience and topics
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'Topic :: Database',
        'Topic :: Software Development :: Version Control',
        'Topic :: Utilities',

        # License
        'License :: OSI Approved :: MIT License',

        # Language
        'Natural Language :: English',

        # Python support
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
    ],

    # What does your project relate to?
    keywords='migrations sqlite3 database development version-control',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(exclude=['contrib', 'docs', 'tests']),

    # Alternatively, if you want to distribute just a my_module.py, uncomment
    # this:
    #   py_modules=["my_module"],

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    install_requires=[],

    # List additional groups of dependencies here (e.g. development
    # dependencies). You can install these using the following syntax,
    # for example:
    # $ pip install -e .[dev,test]
    extras_require={
    },

    # If there are data files included in your packages that need to be
    # installed, specify them here.  If using Python 2.6 or less, then these
    # have to be included in MANIFEST.in as well.
    package_data={
    },

    # Although 'package_data' is the preferred approach, in some case you may
    # need to place data files outside of your packages. See:
    # http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files # noqa
    # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
    data_files=[],

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the target platform.
    entry_points={
        'console_scripts': [
            'limigrations=limigrations.limigrations:main',
        ],
    },
)
